@@ -1,10 +1,10 @@
 /*
- *  $Id: libnet_build_ip.c,v 1.3 1999/10/27 01:37:22 route Exp $
+ *  $Id: libnet_build_ip.c,v 1.1.1.1 2000/05/25 00:28:49 route Exp $
  *
  *  libnet
  *  libnet_build_ip.c - IP packet assembler
  *
- *  Copyright (c) 1998, 1999, 2000 Mike D. Schiffman <mike@infonexus.com>
+ *  Copyright (c) 1998 - 2001 Mike D. Schiffman <mike@infonexus.com>
  *  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -35,6 +35,17 @@
 #endif
 #include "../include/libnet.h"
 
+
+int
+libnet_build_ipv4(u_short len, u_char tos, u_short id, u_short frag,
+            u_char ttl, u_char prot, u_long src, u_long dst,
+            const u_char *payload, int payload_s, u_char *buf)
+{
+    return (libnet_build_ip(len, tos, id, frag, ttl, prot, src, dst, payload,
+            payload_s, buf));
+}
+
+
 int
 libnet_build_ip(u_short len, u_char tos, u_short id, u_short frag, u_char ttl,
             u_char prot, u_long src, u_long dst, const u_char *payload,
