@@ -1,10 +1,10 @@
 /*
- *  $Id: libnet_if_addr.c,v 1.4 1999/10/27 01:37:25 route Exp $
+ *  $Id: libnet_if_addr.c,v 1.1.1.1 2000/05/25 00:28:49 route Exp $
  *
  *  libnet
  *  libnet_if_addr.c - interface selection code
  *
- *  Copyright (c) 1998, 1999, 2000 Mike D. Schiffman <mike@infonexus.com>
+ *  Copyright (c) 1998 - 2001 Mike D. Schiffman <mike@infonexus.com>
  *  Originally pulled from traceroute sources.
  *  All rights reserved.
  *
@@ -151,7 +151,7 @@ libnet_ifaddrlist(register struct libnet_ifaddr_list **ipaddrp,
 #endif  /* !__solaris__ */
 
 int
-libnet_select_device(struct sockaddr_in *sin, u_char **device, u_char *errbuf)
+libnet_select_device(struct sockaddr_in *sin, char **device, char *errbuf)
 {
     int c, i;
     char err_buf[BUFSIZ];
@@ -206,7 +206,7 @@ libnet_select_device(struct sockaddr_in *sin, u_char **device, u_char *errbuf)
 #if (__DEBUG)
             fprintf(stdout,
                 "Multiple interfaces found, using %s @ %s.\n",
-                host_lookup(sin->sin_addr.s_addr, 0),
+                libnet_host_lookup(sin->sin_addr.s_addr, 0),
                 address_list->device);
 #endif
         }
